@@ -225,6 +225,7 @@
 #' (x <- with(DATA2, as.Corpus(state, list(person, class, day))))
 #' library(tm)
 #' inspect(x)
+#' inspect_text(x)
 #' class(x)
 #' 
 #' (y <- with(pres_debates2012, as.Corpus(dialogue, list(person, time))))
@@ -310,7 +311,7 @@
 #' dat[[2]] <- rm_default(dat[[2]], pattern=pastex("@@rm_url", "#apple\\b"))
 #' 
 #' 
-#' myCorp <- tm::tm_map(myCorp, tm::removeWords, stopwords)
+#' myCorp <- tm::tm_map(crude, tm::removeWords, Top200Words)
 #' myCorp %>% as.dtm() %>% tm::inspect()
 #' }
 as.tdm <- function(text.var, grouping.var = NULL, vowel.check = TRUE, ...) {
@@ -512,14 +513,14 @@ as.dtm.wfm <-
 
 wfm2xtab <- function(text.var, grouping.var = NULL, ...) {
   
-    if (!is(text.var, "true.matrix")) {
+    if (!methods::is(text.var, "true.matrix")) {
         text.var <- wfm(text.var = text.var, grouping.var = grouping.var, 
             output = "raw", ...)
     }
     
     d <- melt(text.var)
     colnames(d)[1:2] <- c("Terms", "Docs")
-    xtabs(value ~ Terms + Docs, d)
+    stats::xtabs(value ~ Terms + Docs, d)
 }
 
 
@@ -547,17 +548,28 @@ wfm2xtab <- function(text.var, grouping.var = NULL, ...) {
 as.data.frame.Corpus <- function(x, row.names, optional, ..., doc = "docs", 
     text = "text", sent.split = FALSE) {
 
-    if(!is(x[[1]], "PlainTextDocument")) {
+    if(!methods::is(x[[1]], "PlainTextDocument")) {
         x <- tm::tm_map(x, PlainTextDocument)
     }
 
     qpaste <- function(x) paste(as.character(x), collapse = " ")
-    out <- list2df(lapply(x, qpaste), col1 = text, col2 = doc)[, 2:1]
+    out <- qdapTools::list2df(lapply(x, qpaste), col1 = text, col2 = doc)[, 2:1]
 
     metadat <- NLP::meta(x)
+
+    if (all(unlist(lapply(NLP::meta(x, tag = "labels"), is.null)))){
+        NLP::meta(x, tag = "labels") <- paste("doc", qdapTools::pad(seq_len(length(x))))
+        metadat <- NLP::meta(x)
+    }
+
     if(!is.null(metadat[["labels"]])) {
         out[[1]] <- metadat[["labels"]]
-    } 
+        if (!is.null(metadat[["MetaID"]]) && all.equal(metadat[["labels"]], metadat[["MetaID"]])){
+            metadat[["MetaID"]] <- NULL
+        }
+        colnames(metadat)[colnames(metadat) == "labels"] <- doc
+    }
+
     if (ncol(metadat) > 1 && all(out[[1]] %in% metadat[[1]])) {
         colnames(metadat)[1] <- doc
         out <- key_merge(out, metadat)
@@ -573,7 +585,6 @@ as.data.frame.Corpus <- function(x, row.names, optional, ..., doc = "docs",
     out
 }
 
-
 #' tm Package Compatibility Tools: Apply to or Convert to/from Term Document 
 #' Matrix or Document Term Matrix
 #' 
@@ -597,6 +608,8 @@ as.Corpus <- function(text.var, grouping.var = NULL, demographic.vars, ...){
     UseMethod("as.Corpus")
 }    
 
+
+
 #' \code{as.Corpus.sent_split} - \code{sent_split} Method for \code{as.Corpus}.
 #' @rdname as.tdm
 #' @export
@@ -825,7 +838,7 @@ apply_as_tm <- function(wfm.obj, tmfun, ..., to.qdap = TRUE){
     y <- tmfun(x, ...) 
 
     ## attempt to coerce back to qdap wfm/weighted_wfm
-    if (to.qdap && (is(y, "DocumentTermMatrix")|is(y, "TermDocumentMatrix"))) {
+    if (to.qdap && (methods::is(y, "DocumentTermMatrix")|methods::is(y, "TermDocumentMatrix"))) {
         tm2qdap(y)
     } else {
         y
